@@ -17,14 +17,6 @@ import sys
 from unittest import TestCase
 
 from validations_libs.cli import app
-from validations_libs.cli import base
-from validations_libs import utils
-
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
 
 
 class BaseCommand(TestCase):
@@ -58,5 +50,5 @@ KEYVALUEACTION_VALUES = {
     'invalid_noeq': 'foo>bar',
     'invalid_multieq': 'foo===bar',
     'invalid_nokey': '=bar',
-    'invalid_multikey': 'foo=bar,fizz=buzz'
+    'invalid_multikey': 'foo=bar,baz=,fizz=buzz,baz'
 }
