@@ -24,6 +24,7 @@ from unittest import TestCase
 
 from validations_libs.tests import fakes
 from validations_libs.validation_actions import ValidationActions
+from validations_libs.exceptions import ValidationRunException, ValidationShowException
 
 
 class TestValidationActions(TestCase):
@@ -250,7 +251,7 @@ class TestValidationActions(TestCase):
         mock_validation_play.return_value = []
 
         run = ValidationActions()
-        self.assertRaises(RuntimeError, run.run_validations,
+        self.assertRaises(ValidationRunException, run.run_validations,
                           validation_name=['fake'],
                           validations_dir='/tmp/foo')
 
@@ -263,10 +264,10 @@ class TestValidationActions(TestCase):
             run.run_validations(
                           validation_name=['fake', 'foo'],
                           validations_dir='/tmp/foo')
-        except RuntimeError as runtime_error:
+        except ValidationRunException as run_exception:
             self.assertEqual(
                     "Following validations were not found in '/tmp/foo': foo",
-                    str(runtime_error))
+                    str(run_exception))
         else:
             self.fail("Runtime error exception should have been raised")
 
@@ -275,7 +276,7 @@ class TestValidationActions(TestCase):
         mock_validation_play.return_value = []
 
         run = ValidationActions()
-        self.assertRaises(RuntimeError, run.run_validations,
+        self.assertRaises(ValidationRunException, run.run_validations,
                           validations_dir='/tmp/foo'
                           )
 
@@ -386,7 +387,7 @@ class TestValidationActions(TestCase):
         inventory = 'tmp/inventory.yaml'
 
         run = ValidationActions()
-        self.assertRaises(RuntimeError, run.run_validations, playbook,
+        self.assertRaises(ValidationRunException, run.run_validations, playbook,
                           inventory)
 
     @mock.patch('validations_libs.utils.parse_all_validations_on_disk',
@@ -396,7 +397,7 @@ class TestValidationActions(TestCase):
     @mock.patch('validations_libs.validation_logs.ValidationLogs.'
                 'get_logfile_content_by_validation',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists', return_value=True)
     def test_validation_show(self, mock_exists, mock_open,
                              mock_parse_validation, mock_data, mock_log):
@@ -418,7 +419,7 @@ class TestValidationActions(TestCase):
     def test_validation_show_not_found(self, mock_exists):
         validations_show = ValidationActions()
         self.assertRaises(
-            RuntimeError,
+            ValidationShowException,
             validations_show.show_validations,
             '512e'
         )
@@ -426,7 +427,7 @@ class TestValidationActions(TestCase):
     @mock.patch('validations_libs.utils.parse_all_validations_on_disk',
                 return_value=fakes.VALIDATIONS_LIST)
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_group_information(self, mock_open, mock_yaml, mock_data):
         v_actions = ValidationActions()
         col, values = v_actions.group_information()
@@ -436,28 +437,28 @@ class TestValidationActions(TestCase):
                                   ('post', 'post-foo', 2),
                                   ('pre', 'pre-foo', 1)])
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters_wrong_validations_type(self, mock_open):
         v_actions = ValidationActions()
         self.assertRaises(TypeError,
                           v_actions.show_validations_parameters,
                           validations='foo')
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters_wrong_groups_type(self, mock_open):
         v_actions = ValidationActions()
         self.assertRaises(TypeError,
                           v_actions.show_validations_parameters,
                           groups=('foo'))
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters_wrong_categories_type(self, mock_open):
         v_actions = ValidationActions()
         self.assertRaises(TypeError,
                           v_actions.show_validations_parameters,
                           categories={'foo': 'bar'})
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters_wrong_products_type(self, mock_open):
         v_actions = ValidationActions()
         self.assertRaises(TypeError,
@@ -468,7 +469,7 @@ class TestValidationActions(TestCase):
                 return_value=['/foo/playbook/foo.yaml'])
     @mock.patch('validations_libs.utils.get_validations_parameters')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters(self, mock_open, mock_load,
                                          mock_get_param, mock_get_play):
         mock_get_param.return_value = {'foo':
@@ -477,10 +478,10 @@ class TestValidationActions(TestCase):
         result = v_actions.show_validations_parameters(validations=['foo'])
         self.assertEqual(result, mock_get_param.return_value)
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_validations_parameters_non_supported_format(self, mock_open):
         v_actions = ValidationActions()
-        self.assertRaises(RuntimeError,
+        self.assertRaises(ValidationShowException,
                           v_actions.show_validations_parameters,
                           validations=['foo'], output_format='bar')
 
@@ -489,7 +490,7 @@ class TestValidationActions(TestCase):
                 return_value=['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json'])
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_history_str(self, mock_open, mock_load, mock_get_log):
         v_actions = ValidationActions()
         col, values = v_actions.show_history('512e')
@@ -506,7 +507,7 @@ class TestValidationActions(TestCase):
                 return_value=['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json'])
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_history_list(self, mock_open, mock_load, mock_get_log):
         v_actions = ValidationActions()
         col, values = v_actions.show_history(['512e'])
@@ -523,7 +524,7 @@ class TestValidationActions(TestCase):
                 return_value=['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json'])
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_history_all(self, mock_open, mock_load, mock_get_log):
         v_actions = ValidationActions()
         col, values = v_actions.show_history()
@@ -543,7 +544,7 @@ class TestValidationActions(TestCase):
                     '/tmp/123_bar_2020-03-05T13:17:22.447857Z.json'])
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_show_history_most_recent(self, mock_open, mock_load,
                                       mock_get_log, mock_stat):
 
@@ -581,7 +582,7 @@ class TestValidationActions(TestCase):
                 return_value=['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json'])
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_status(self, mock_open, mock_load, mock_get_log):
         v_actions = ValidationActions()
         col, values = v_actions.get_status('foo')
