@@ -16,13 +16,11 @@ import ast
 import configparser
 import datetime
 import glob
-import logging
 import os
 import site
 import subprocess
 import uuid
 
-from os.path import join
 # @matbu backward compatibility for stable/train
 try:
     from pathlib import Path
@@ -32,8 +30,9 @@ except ImportError:
 from validations_libs import constants
 from validations_libs.group import Group
 from validations_libs.validation import Validation
+from validations_libs.logger import getLogger
 
-LOG = logging.getLogger(__name__ + ".utils")
+LOG = getLogger(__name__ + ".utils")
 
 
 def current_time():
@@ -604,8 +603,7 @@ def find_config_file(config_file_name='validation.cfg'):
     return current_path
 
 
-def run_command_and_log(log, cmd, cwd=None,
-                        env=None, retcode_only=True):
+def run_command_and_log(log, cmd, cwd=None, env=None):
     """Run command and log output
 
     :param log: Logger instance for logging
@@ -619,28 +617,23 @@ def run_command_and_log(log, cmd, cwd=None,
 
     :param env: Modified environment for command run
     :type env: ``List``
-
-    :param retcode_only: Returns only retcode instead or proc object
-    :type retcdode_only: ``Boolean``
     """
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
                             stderr=subprocess.STDOUT, shell=False,
                             cwd=cwd, env=env)
-    if retcode_only:
-        while True:
-            try:
-                line = proc.stdout.readline()
-            except StopIteration:
-                break
-            if line != b'':
-                if isinstance(line, bytes):
-                    line = line.decode('utf-8')
-                log.debug(line.rstrip())
-            else:
-                break
-        proc.stdout.close()
-        return proc.wait()
-    return proc
+    while True:
+        try:
+            line = proc.stdout.readline()
+        except StopIteration:
+            break
+        if line != b'':
+            if isinstance(line, bytes):
+                line = line.decode('utf-8')
+            log.debug(line.rstrip())
+        else:
+            break
+    proc.stdout.close()
+    return proc.wait()
 
 
 def check_community_validations_dir(
