@@ -24,7 +24,7 @@ from validations_libs import constants
 LOG = logging.getLogger(__name__ + ".validation_logs")
 
 
-class ValidationLog(object):
+class ValidationLog:
     """An object for encapsulating a Validation Log file"""
 
     def __init__(self, uuid=None, validation_id=None, logfile=None,
@@ -198,17 +198,16 @@ class ValidationLog(object):
     def get_status(self):
         """Return validation status
 
-        :return: 'FAILED' if there is failure(s), 'PASSED' if not.
-                 If no tasks have been executed, it returns 'NOT_RUN'.
+        :return: 'FAILED' if there are any failed or unreachable validations,
+                 'PASSED' if not.
         :rtype: ``string``
         """
-        failed = 0
-        for h in self.content['stats'].keys():
-            if self.content['stats'][h].get('failures'):
-                failed += 1
-            if self.content['stats'][h].get('unreachable'):
-                failed += 1
-        return ('FAILED' if failed else 'PASSED')
+        failure_states = ['failures', 'unreachable']
+
+        for v_stats in self.content['stats'].values():
+            if any([v_stats[failure] != 0 for failure in failure_states]):
+                return 'FAILED'
+        return 'PASSED'
 
     @property
     def get_host_group(self):
@@ -287,6 +286,26 @@ class ValidationLog(object):
                     play in self.content['plays']]
         return ', '.join(filter(None, duration))
 
+    @property
+    def get_reason(self):
+        """Return validation reason
+
+        :return: hostname: reason of the failure
+        :rtype: ``string``
+        """
+        reason = []
+        if self.get_status == 'FAILED':
+            for v_output in self.content['validation_output']:
+                for h in v_output['task']['hosts']:
+                    msg = v_output['task']['hosts'][h].get('msg',
+                                                           'Unknown')
+                    msg = msg[:50] + '\n' + msg[50:]
+                    reason.append('{}: {}'.format(h, msg))
+            if not self.content['validation_output']:
+                if self.get_unreachable_hosts:
+                    reason.append('Unreachable')
+        return ',\n'.join(reason)
+
     @property
     def get_start_time(self):
         """Return Ansible start time
@@ -539,5 +558,6 @@ class ValidationLogs(object):
             data['Status_by_Host'] = vlog.get_hosts_status
             data['Unreachable_Hosts'] = vlog.get_unreachable_hosts
             data['Duration'] = vlog.get_duration
+            data['Reasons'] = vlog.get_reason
             res.append(data)
         return res
